@@ -1,9 +1,9 @@
 context("pg_identify")
 
 test_that("pg_identify works", {
-  skip_on_cran()
-
-  aa <- pg_identify()
+  vcr::use_cassette("pg_identify2", {
+    aa <- pg_identify()
+  })
 
   expect_is(aa, "pg_identify")
   expect_is(unclass(aa), "list")
